@@ -14,6 +14,8 @@ extern "C" {
 #define R_IO_WRITE (1 << 1)
 #define R_IO_READ  (1 << 2)
 #define R_IO_MAP   (1 << 4)
+#define R_IO_PRIV  (1 << 5)
+#define R_IO_SHAR  (1 << 6)
 #define R_IO_RW    (R_IO_READ | R_IO_WRITE)
 
 #define R_IO_SEEK_SET 0
@@ -161,6 +163,8 @@ typedef struct r_io_t {
 	void *user;
 	int (*cb_core_cmd)(void *user, const char *str);
 	char* (*cb_core_cmdstr)(void *user, const char *str);
+	/* Used for comment generation */
+	void (*cb_core_post_write)(void *user, ut64 maddr, ut8 *orig_bytes, int orig_len);
 	struct r_io_plugin_t *plugin_default;
 } RIO;
 
@@ -294,6 +298,7 @@ R_API int r_io_plugin_generate(RIO *io);
 R_API bool r_io_plugin_add(RIO *io, RIOPlugin *plugin);
 R_API int r_io_plugin_list(RIO *io);
 R_API int r_io_is_listener(RIO *io);
+R_API bool r_io_is_blockdevice(RIO *io);
 
 R_API RIOPlugin *r_io_plugin_byname(RIO *io, const char *name);
 R_API RIOPlugin *r_io_plugin_resolve(RIO *io, const char *filename, bool many);
@@ -387,7 +392,6 @@ R_API void r_io_section_free(void *ptr);
 R_API RIOSection *r_io_section_add(RIO *io, ut64 offset, ut64 vaddr, ut64 size, ut64 vsize, int rwx, const char *name, ut32 bin_id, int fd);
 R_API RIOSection *r_io_section_get_name(RIO *io, const char *name);
 R_API RIOSection *r_io_section_get_i(RIO *io, int idx);
-R_API RIOSection *r_io_section_getv(RIO *io, ut64 vaddr);
 R_API RIOSection *r_io_section_mget_in(RIO *io, ut64 maddr);
 R_API RIOSection *r_io_section_mget_prev(RIO *io, ut64 maddr);
 R_API RIOSection *r_io_section_vget(RIO *io, ut64 addr);
